document.addEventListener('DOMContentLoaded', () => {
    let shows = [];
    let currentGenre = 'all';

    // Simulated TV show data fetch
    async function fetchTVShows() {
        try {
            // In reality, this would be an API call
            const response = await new Promise(resolve => setTimeout(() => {
                resolve({
                    shows: [
                        {
                            title: "Doctor Who",
                            genre: "drama",
                            time: "19:00",
                            rating: 8.9,
                            channel: "BBC One",
                            image: "data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 100 100'%3E%3Crect width='100' height='100' fill='%233498db'/%3E%3C/svg%3E"
                        },
                        // Add more shows here
                    ]
                });
            }, 1000));
            
            shows = response.shows;
            renderShows();
        } catch (error) {
            console.error('Error fetching shows:', error);
            document.getElementById('shows-container').innerHTML = 
                '<div class="error">Error loading shows. Please try again later.</div>';
        }
    }

    function renderShows() {
        const container = document.getElementById('shows-container');
        const filteredShows = shows.filter(show => 
            currentGenre === 'all' || show.genre === currentGenre
        );

        const showsHTML = filteredShows.map(show => `
            <article class="show-card">
                <img src="${show.image}" alt="${show.title}">
                <div class="show-info">
                    <h2 class="show-title">${show.title}</h2>
                    <div class="show-meta">
                        <span>${show.time} on ${show.channel}</span>
                        <div class="rating">★ ${show.rating}</div>
                    </div>
                    <div class="genre-tag">${show.genre}</div>
                </div>
            </article>
        `).join('');

        container.innerHTML = showsHTML || '<div class="no-shows">No shows found</div>';
    }

    // Event Listeners
    document.querySelectorAll('.genre-filter').forEach(button => {
        button.addEventListener('click', (e) => {
            document.querySelector('.genre-filter.active').classList.remove('active');
            e.target.classList.add('active');
            currentGenre = e.target.dataset.genre;
            renderShows();
        });
    });

    document.getElementById('sort-by').addEventListener('change', (e) => {
        const sortBy = e.target.value;
        shows.sort((a, b) => {
            if (sortBy === 'rating') return b.rating - a.rating;
            if (sortBy === 'time') return a.time.localeCompare(b.time);
            return a.title.localeCompare(b.title);
        });
        renderShows();
    });

    // Initial load
    fetchTVShows();
});
